@@ -422,7 +422,7 @@ class Shvar(RememberInstanceCreationInfo):
                 if isinstance(x, (int, float)) is False:
                     raise TypeError("The first argument(mean) should be a list of numbers.")
             for y in args[1]:
-                if (isinstance(y, (int, float)) and y > 0) is False:
+                if (isinstance(y, (int, float)) and y >= 0) is False:
                     raise TypeError("The second argument(SE) should be a list of positive numbers.")
             self.mean = args[0]
             self.SE = [np.sqrt(s**2 + self.tbe**2) for s in args[1]]
